@@ -7,10 +7,10 @@
 #define ADIOSCONFIG_H_
 
 /* ADIOS Version Information */
-#define ADIOS2_VERSION_STR   "2.9.2"
+#define ADIOS2_VERSION_STR   "2.10.0"
 #define ADIOS2_VERSION_MAJOR 2
-#define ADIOS2_VERSION_MINOR 9
-#define ADIOS2_VERSION_PATCH 2
+#define ADIOS2_VERSION_MINOR 10
+#define ADIOS2_VERSION_PATCH 0
 /* #undef ADIOS2_VERSION_TWEAK */
 
 #define ADIOS2_VERSION (ADIOS2_VERSION_MAJOR* 10000 + ADIOS2_VERSION_MINOR * 100 + ADIOS2_VERSION_PATCH)
@@ -30,107 +30,119 @@
 /* Everything between here and the note below is programatically generated */
 
 
-/* CMake Option: ADIOS_USE_BP5=OFF */
-#define ADIOS2_HAVE_BP5
-
-/* CMake Option: ADIOS_USE_DataMan=OFF */
+/* CMake Option: ADIOS2_USE_DataMan=OFF */
 #define ADIOS2_HAVE_DATAMAN
 
-/* CMake Option: ADIOS_USE_DataSpaces=OFF */
+/* CMake Option: ADIOS2_USE_DataSpaces=OFF */
 /* #undef ADIOS2_HAVE_DATASPACES */
 
-/* CMake Option: ADIOS_USE_HDF5=OFF */
+/* CMake Option: ADIOS2_USE_HDF5=OFF */
 #define ADIOS2_HAVE_HDF5
 
-/* CMake Option: ADIOS_USE_HDF5_VOL=OFF */
+/* CMake Option: ADIOS2_USE_HDF5_VOL=OFF */
 /* #undef ADIOS2_HAVE_HDF5_VOL */
 
-/* CMake Option: ADIOS_USE_MHS=OFF */
+/* CMake Option: ADIOS2_USE_MHS=OFF */
 #define ADIOS2_HAVE_MHS
 
-/* CMake Option: ADIOS_USE_SST=OFF */
+/* CMake Option: ADIOS2_USE_SST=OFF */
 #define ADIOS2_HAVE_SST
 
-/* CMake Option: ADIOS_USE_Fortran=OFF */
+/* CMake Option: ADIOS2_USE_Fortran=OFF */
 #define ADIOS2_HAVE_FORTRAN
 
-/* CMake Option: ADIOS_USE_MPI=OFF */
+/* CMake Option: ADIOS2_USE_MPI=OFF */
 #define ADIOS2_HAVE_MPI
 
-/* CMake Option: ADIOS_USE_Python=OFF */
+/* CMake Option: ADIOS2_USE_Python=OFF */
 #define ADIOS2_HAVE_PYTHON
 
-/* CMake Option: ADIOS_USE_Blosc2=OFF */
+/* CMake Option: ADIOS2_USE_PIP=OFF */
+/* #undef ADIOS2_HAVE_PIP */
+
+/* CMake Option: ADIOS2_USE_Blosc2=OFF */
 /* #undef ADIOS2_HAVE_BLOSC2 */
 
-/* CMake Option: ADIOS_USE_BZip2=OFF */
+/* CMake Option: ADIOS2_USE_BZip2=OFF */
 #define ADIOS2_HAVE_BZIP2
 
-/* CMake Option: ADIOS_USE_LIBPRESSIO=OFF */
+/* CMake Option: ADIOS2_USE_LIBPRESSIO=OFF */
 /* #undef ADIOS2_HAVE_LIBPRESSIO */
 
-/* CMake Option: ADIOS_USE_MGARD=OFF */
+/* CMake Option: ADIOS2_USE_MGARD=OFF */
 /* #undef ADIOS2_HAVE_MGARD */
 
-/* CMake Option: ADIOS_USE_PNG=OFF */
+/* CMake Option: ADIOS2_USE_MGARD_MDR=OFF */
+/* #undef ADIOS2_HAVE_MGARD_MDR */
+
+/* CMake Option: ADIOS2_USE_PNG=OFF */
 #define ADIOS2_HAVE_PNG
 
-/* CMake Option: ADIOS_USE_SZ=OFF */
+/* CMake Option: ADIOS2_USE_SZ=OFF */
 #define ADIOS2_HAVE_SZ
 
-/* CMake Option: ADIOS_USE_ZFP=OFF */
+/* CMake Option: ADIOS2_USE_ZFP=OFF */
 #define ADIOS2_HAVE_ZFP
 
-/* CMake Option: ADIOS_USE_DAOS=OFF */
+/* CMake Option: ADIOS2_USE_DAOS=OFF */
 /* #undef ADIOS2_HAVE_DAOS */
 
-/* CMake Option: ADIOS_USE_IME=OFF */
+/* CMake Option: ADIOS2_USE_IME=OFF */
 /* #undef ADIOS2_HAVE_IME */
 
-/* CMake Option: ADIOS_USE_O_DIRECT=OFF */
+/* CMake Option: ADIOS2_USE_O_DIRECT=OFF */
 #define ADIOS2_HAVE_O_DIRECT
 
-/* CMake Option: ADIOS_USE_Sodium=OFF */
+/* CMake Option: ADIOS2_USE_Sodium=OFF */
 #define ADIOS2_HAVE_SODIUM
 
-/* CMake Option: ADIOS_USE_Catalyst=OFF */
+/* CMake Option: ADIOS2_USE_Catalyst=OFF */
 /* #undef ADIOS2_HAVE_CATALYST */
 
-/* CMake Option: ADIOS_USE_SysVShMem=OFF */
+/* CMake Option: ADIOS2_USE_SysVShMem=OFF */
 #define ADIOS2_HAVE_SYSVSHMEM
 
-/* CMake Option: ADIOS_USE_UCX=OFF */
+/* CMake Option: ADIOS2_USE_UCX=OFF */
 /* #undef ADIOS2_HAVE_UCX */
 
-/* CMake Option: ADIOS_USE_ZeroMQ=OFF */
+/* CMake Option: ADIOS2_USE_ZeroMQ=OFF */
 #define ADIOS2_HAVE_ZEROMQ
 
-/* CMake Option: ADIOS_USE_Profiling=OFF */
+/* CMake Option: ADIOS2_USE_Profiling=OFF */
 #define ADIOS2_HAVE_PROFILING
 
-/* CMake Option: ADIOS_USE_Endian_Reverse=OFF */
+/* CMake Option: ADIOS2_USE_Endian_Reverse=OFF */
 /* #undef ADIOS2_HAVE_ENDIAN_REVERSE */
 
-/* CMake Option: ADIOS_USE_AWSSDK=OFF */
+/* CMake Option: ADIOS2_USE_Derived_Variable=OFF */
+/* #undef ADIOS2_HAVE_DERIVED_VARIABLE */
+
+/* CMake Option: ADIOS2_USE_AWSSDK=OFF */
 /* #undef ADIOS2_HAVE_AWSSDK */
 
-/* CMake Option: ADIOS_USE_GPU_Support=OFF */
+/* CMake Option: ADIOS2_USE_GPU_Support=OFF */
 /* #undef ADIOS2_HAVE_GPU_SUPPORT */
 
-/* CMake Option: ADIOS_USE_CUDA=OFF */
+/* CMake Option: ADIOS2_USE_CUDA=OFF */
 /* #undef ADIOS2_HAVE_CUDA */
 
-/* CMake Option: ADIOS_USE_Kokkos=OFF */
+/* CMake Option: ADIOS2_USE_Kokkos=OFF */
 /* #undef ADIOS2_HAVE_KOKKOS */
 
-/* CMake Option: ADIOS_USE_Kokkos_CUDA=OFF */
+/* CMake Option: ADIOS2_USE_Kokkos_CUDA=OFF */
 /* #undef ADIOS2_HAVE_KOKKOS_CUDA */
 
-/* CMake Option: ADIOS_USE_Kokkos_HIP=OFF */
+/* CMake Option: ADIOS2_USE_Kokkos_HIP=OFF */
 /* #undef ADIOS2_HAVE_KOKKOS_HIP */
 
+/* CMake Option: ADIOS2_USE_Kokkos_SYCL=OFF */
+/* #undef ADIOS2_HAVE_KOKKOS_SYCL */
 
-#define ADIOS2_FEATURE_LIST "BP5","DATAMAN","HDF5","MHS","SST","FORTRAN","MPI","PYTHON","BZIP2","PNG","SZ","ZFP","O_DIRECT","SODIUM","SYSVSHMEM","ZEROMQ","PROFILING",nullptr
+/* CMake Option: ADIOS2_USE_Campaign=OFF */
+#define ADIOS2_HAVE_CAMPAIGN
+
+
+#define ADIOS2_FEATURE_LIST "DATAMAN","HDF5","MHS","SST","FORTRAN","MPI","PYTHON","BZIP2","PNG","SZ","ZFP","O_DIRECT","SODIUM","SYSVSHMEM","ZEROMQ","PROFILING","CAMPAIGN",nullptr
 
 /* Everything between here and the note above is programatically generated */
 
