@@ -26,8 +26,6 @@ class Group;  // friend
 namespace core
 {
 
-class VariableBase;
-
 template <class T>
 class Variable; // private implementation
 
@@ -141,20 +139,40 @@ public:
      * variables from IO:DefineVariable<T> or IO:InquireVariable<T>.
      * Can be used with STL containers.
      */
-    Variable<T>() = default;
+    Variable() = default;
 
     /** Default, using RAII STL containers */
-    ~Variable<T>() = default;
+    ~Variable() = default;
 
     /** Checks if object is valid, e.g. if( variable ) { //..valid } */
     explicit operator bool() const noexcept;
 
     /**
-     * Sets the memory space for all following Puts
+     * Sets the memory space for all following Puts/Gets
+     * to either host (default) or device
+     * @param mem memory space where Put/Get buffers are allocated
+     */
+    void SetMemorySpace(const MemorySpace mem);
+
+    /**
+     * Get the memory space that was set by the application
+     * @return the memory space stored in the Variable object
+     */
+    MemorySpace GetMemorySpace();
+
+#if defined(ADIOS2_HAVE_KOKKOS) || defined(ADIOS2_HAVE_GPU_SUPPORT)
+    /**
+     * Sets the  for all following Puts
      * to either host (default) or device (currently only CUDA supported)
      * @param mem memory space where Put buffers are allocated
      */
-    void SetMemorySpace(const MemorySpace mem);
+    void SetArrayLayout(const adios2::ArrayOrdering layout);
+    /**
+     * Get the memory space that was set by the application
+     * @return the memory space stored in the Variable object
+     */
+    adios2::ArrayOrdering GetArrayLayout();
+#endif
 
     /**
      * Set new shape, care must be taken when reading back the variable for
@@ -205,6 +223,12 @@ public:
      */
     void SetStepSelection(const adios2::Box<size_t> &stepSelection);
 
+    /**
+     * Sets the requested accuracy for the next read operation.
+     * The actual accuracy after the read is provided in GetAccuracy()
+     */
+    void SetAccuracy(const adios2::Accuracy &a);
+
     /**
      * Returns the number of elements required for pre-allocation based on
      * current count and stepsCount
@@ -245,6 +269,10 @@ public:
      * @return shape vector
      */
     adios2::Dims Shape(const size_t step = adios2::EngineCurrentStep) const;
+    adios2::Dims Shape(const ArrayOrdering layout,
+                       const size_t step = adios2::EngineCurrentStep) const;
+    adios2::Dims Shape(const MemorySpace memSpace,
+                       const size_t step = adios2::EngineCurrentStep) const;
 
     /**
      * Inspects current start point
@@ -259,13 +287,13 @@ public:
     adios2::Dims Count() const;
 
     /**
-     * For read mode, inspect the number of available steps
+     * For readRandomAccess mode, inspect the number of available steps
      * @return available steps
      */
     size_t Steps() const;
 
     /**
-     * For read mode, inspect the start step for available steps
+     * For readRandomAccess mode, inspect the start step for available steps
      * @return available start step
      */
     size_t StepsStart() const;
@@ -284,8 +312,7 @@ public:
      * be confused by op own parameters
      * @return operation index handler in Operations()
      */
-    size_t AddOperation(const Operator op,
-                        const adios2::Params &parameters = adios2::Params());
+    size_t AddOperation(const Operator op, const adios2::Params &parameters = adios2::Params());
 
     size_t AddOperation(const std::string &type,
                         const adios2::Params &parameters = adios2::Params());
@@ -332,6 +359,13 @@ public:
      */
     T Max(const size_t step = adios2::DefaultSizeT) const;
 
+    /**
+     * Get the provided accuracy for the last read operation.
+     * Most operations provide data as it was written, meaning that
+     * error is reported as 0.0
+     */
+    adios2::Accuracy GetAccuracy();
+
     /** Contains block information for a particular Variable<T> */
     struct Info
     {
@@ -380,32 +414,24 @@ public:
 
     /**
      */
-    std::map<size_t, std::vector<typename Variable<T>::Info>>
-    AllStepsBlocksInfoMap() const;
-
-    std::vector<typename Variable<T>::Info>
-    ToBlocksInfoMin(const MinVarInfo *coreVarInfo) const;
+    std::map<size_t, std::vector<typename Variable<T>::Info>> AllStepsBlocksInfoMap() const;
 
     using Span = adios2::detail::Span<T>;
 
 private:
-    Variable<T>(core::Variable<IOType> *variable);
     core::Variable<IOType> *m_Variable = nullptr;
 
-    std::vector<std::vector<typename Variable<T>::Info>> DoAllStepsBlocksInfo();
-    std::map<size_t, std::vector<typename Variable<T>::Info>>
-    DoAllStepsBlocksInfoMap() const;
-};
+    std::vector<typename Variable<T>::Info> ToBlocksInfoMin(const MinVarInfo *coreVarInfo) const;
 
-#define declare_template_instantiation(T)                                      \
-    extern template std::vector<typename Variable<T>::Info>                    \
-    Variable<T>::ToBlocksInfoMin(const MinVarInfo *coreVarInfo) const;
-ADIOS2_FOREACH_TYPE_1ARG(declare_template_instantiation)
-#undef declare_template_instantiation
+    Variable(core::Variable<IOType> *variable);
+
+    std::vector<std::vector<typename Variable<T>::Info>> DoAllStepsBlocksInfo();
+    std::map<size_t, std::vector<typename Variable<T>::Info>> DoAllStepsBlocksInfoMap() const;
+};
 
 template <typename T>
 std::string ToString(const Variable<T> &variable);
 
 } // end namespace adios2
 
-#endif /* ADIOS2_BINDINGS_CXX11_CXX11_VARIABLE_H_ */
+#endif // ADIOS2_BINDINGS_CXX11_CXX11_VARIABLE_H_
